Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type EachDOM ¶
type EachDOM func(io.ReadCloser, error) error
EachDOM provides a walking function for a substream
type Matcher ¶
type Matcher func(xml.StartElement) bool
Matcher provides a swappable matcher for finding elems
type MiniDom ¶
type MiniDom struct {
// StartFunc listens to start elems outside of Prefix
StartFunc func(xml.StartElement)
// EndFunc listens to the end elems outside of Prefix, bool returns whether an exit is requested
EndFunc func(xml.EndElement) bool
}
MiniDom provides the lifecycle management for walking streams of doms
Click to show internal directories.
Click to hide internal directories.